@@ -3,7 +3,7 @@
 
 //
 //  NetBSD port:  
-//  Copyright (c) 1995, 1996, 1997 by Brian Grayson (bgrayson@ece.utexas.edu)
+//  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
 //    projects.
@@ -46,7 +46,7 @@ void
 BSDGetCPUTimes(long* timesArray);
 #endif
 
-void
+int
 BSDNetInit();
 
 void
@@ -57,7 +57,7 @@ BSDSwapInit();
 
 #ifdef HAVE_SWAPCTL
 void
-BSDGetSwapCtlInfo(int* total, int* free);
+BSDGetSwapCtlInfo(unsigned long long* total, unsigned long long* free);
 #endif
 
 int
