@@ -1,5 +1,5 @@
 //
-//  Copyright (c) 1999 by Mike Romberg (romberg@fsl.noaa.gov)
+//  Copyright (c) 1999, 2006 by Mike Romberg (mike.romberg@noaa.gov)
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -21,11 +21,21 @@ class DiskMeter : public FieldMeterGraph
         void checkResources( void );
     protected:
 
+	// sysfs:
+	void update_info(unsigned long long rsum, unsigned long long wsum);
+	void getsysfsdiskinfo( void );
+
         void getdiskinfo( void );
         void getvmdiskinfo( void );
         void updateinfo(unsigned long one, unsigned long two,
           int fudgeFactor);
     private:
+
+	// sysfs:
+	unsigned long long sysfs_read_prev_;
+	unsigned long long sysfs_write_prev_;
+        bool _sysfs;
+
         unsigned long int read_prev_;
         unsigned long int write_prev_;
         float maxspeed_;
