@@ -1,12 +1,12 @@
 //
-//  Copyright (c) 2000 by Leopold Toetsch <lt@toetsch.at>
+//  Copyright (c) 2000, 2006 by Leopold Toetsch <lt@toetsch.at>
 //
 //  Read temperature entries from /proc/sys/dev/sensors/*/*
 //  and display actual and high temperature
 //  if actual >= high, actual temp changes color to indicate alarm
 //
 //  File based on btrymeter.* by
-//  Copyright (c) 1997 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1997 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -145,7 +145,7 @@ void LmsTemp::getlmstemp( void ){
     return;
   }
 
-  int dummy, high;
+  double dummy, high;
   total_ = _highest;  // Max temp
   file >> high >> dummy >> fields_[0];
   fields_[1] = high - fields_[0];
