@@ -1,5 +1,5 @@
 //
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -11,14 +11,20 @@
 #include "loadmeter.h"
 #include "xosview.h"
 #include <fstream>
+#include <sstream>
 #include <stdlib.h>
 
 static const char LOADFILENAME[] = "/proc/loadavg";
+static const char SPEEDFILENAME[] = "/proc/cpuinfo";
+
 
 LoadMeter::LoadMeter( XOSView *parent )
   : FieldMeterGraph( parent, 2, "LOAD", "PROCS/MIN", 1, 1, 0 ){
   lastalarmstate = -1;
   total_ = 2.0;
+  old_cpu_speed_= cur_cpu_speed_=0;
+  do_cpu_speed = 0;
+
 }
 
 LoadMeter::~LoadMeter( void ){
@@ -41,6 +47,7 @@ void LoadMeter::checkResources( void ){
   warnThreshold = atoi (parent_->getResource("loadWarnThreshold"));
   critThreshold = atoi (parent_->getResource("loadCritThreshold"));
 
+  do_cpu_speed  = parent_->isResourceTrue( "loadCpuSpeed" );
 
   if (dodecay_){
     //  Warning:  Since the loadmeter changes scale occasionally, old
@@ -58,6 +65,21 @@ void LoadMeter::checkResources( void ){
 
 void LoadMeter::checkevent( void ){
   getloadinfo();
+  if ( do_cpu_speed ) {
+         getspeedinfo();
+         if ( old_cpu_speed_ != cur_cpu_speed_ ) {
+        // update the legend:
+        std::ostringstream legnd;
+        XOSDEBUG("SPEED: %d\n",cur_cpu_speed_);
+        legnd << "PROCS/MIN" << " " << cur_cpu_speed_ << " MHz"<< std::ends;
+            legend( legnd.str().c_str() );
+        if (dolegends_) {
+                        drawlegend();
+                        parent_->reallydraw();
+                }
+     }
+  }
+
   drawfields();
 }
 
@@ -102,3 +124,34 @@ void LoadMeter::getloadinfo( void ){
 
   setUsed(fields_[0], (float) 1.0);
 }
+// just check /proc/cpuinfo for the speed of cpu0
+// (be ignorant on multi-cpus being on different speeds)
+// display is intended mainly for laptops ...
+// (yes - i know about devices/system/cpu/cpu0/cpufreq )
+void LoadMeter::getspeedinfo( void ){
+
+  std::string filename;
+  std::ifstream speedinfo;
+  std::string inp_line;
+
+  std::string argname;
+  std::string argval;
+
+  speedinfo.open(SPEEDFILENAME );
+  while ( speedinfo.good() ) {
+    argname.clear();
+    std::getline(speedinfo,argname,':');
+    argval.clear();
+    std::getline(speedinfo,argval);
+        // XOSDEBUG("speed: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
+
+    if ( argname.substr(0,7) == "cpu MHz" ) {
+        //XOSDEBUG("SPEED: %s\n",argval.c_str() );
+        old_cpu_speed_ = cur_cpu_speed_;
+        cur_cpu_speed_ = atoi(argval.c_str());
+        break;
+    }
+  }
+  speedinfo.close(); speedinfo.clear();
+
+}
