@@ -1,5 +1,5 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -20,7 +20,7 @@ public:
   LoadMeter( XOSView *parent );
   ~LoadMeter( void );
 
-  const char *name( void ) const { return "LoadMeter"; }  
+  const char *name( void ) const { return "LoadMeter"; }
   void checkevent( void );
 
   void checkResources( void );
@@ -28,8 +28,12 @@ protected:
 
   void getloadinfo( void );
   unsigned long procloadcol_, warnloadcol_, critloadcol_;
+  void getspeedinfo( void );
+
 private:
-  int warnThreshold, critThreshold, alarmstate, lastalarmstate;
+   int warnThreshold, critThreshold, alarmstate, lastalarmstate;
+   int old_cpu_speed_, cur_cpu_speed_;
+   int do_cpu_speed;
 };
 
 
