@@ -1,5 +1,5 @@
 //
-//  Copyright (c) 1994, 1995, 2002 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2002, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  Modifications to support dynamic addresses by:
 //    Michael N. Lipp (mnl@dtro.e-technik.th-darmstadt.de)
@@ -119,6 +119,7 @@ void NetMeter::checkResources( void ){
   useGraph_ = parent_->isResourceTrue( "netGraph" );
   dodecay_ = parent_->isResourceTrue( "netDecay" );
   SetUsedFormat (parent_->getResource("netUsedFormat"));
+  netIface_ = parent_->getResource( "netIface" );
 
   _ipsock = socket(AF_INET, SOCK_DGRAM, 0);
   if (_ipsock == -1) {
@@ -148,8 +149,8 @@ void NetMeter::checkeventNew(void)
         }
 
     std::string str_in;
-    unsigned long in, out, ig;
-    unsigned long totin = 0, totout = 0;
+    unsigned long long in, out, ig;
+    unsigned long long totin = 0, totout = 0;
     char buf[1024];
 
     fields_[2] = maxpackets_;     // assume no
@@ -171,18 +172,35 @@ void NetMeter::checkeventNew(void)
         }
     else
         {
+	  std::string ifname;
 	  ifs.ignore(1024, '\n');
 	  ifs.ignore(1024, '\n');
 
 	  while (ifs)
 	      {
-	      ifs.ignore(1024, ':');
-              ifs >> str_in;
+		if (netIface_ == "False" ) 
+		  {
+		    ifs.ignore(1024, ':');
+		  }
+		else
+		  {
+		    ifs.get(buf, 128, ':');
+		    ifname = buf;
+		    ifs.ignore(1, ':');
+		    ifname.erase(0, ifname.find_first_not_of(" ") );
+		    if (ifname != netIface_) 
+		      {
+			ifs.ignore(1024,'\n');
+			continue;
+		      }
+		  }
+
+	      ifs >> str_in;
               if (str_in == "No")
                 continue;
               else
                 {
-                  in = strtoul(str_in.c_str(), NULL, 10);
+                  in = strtoull(str_in.c_str(), NULL, 10);
                   ifs >> ig >> ig >> ig >> ig >> ig >> ig >> ig >> out;
                 }
 
@@ -242,8 +260,8 @@ void NetMeter::checkeventOld(void)
         }
 
     char c;
-    unsigned long sa, da, sm, dm, bytes;
-    unsigned long tot_in = 0, tot_out = 0;
+    unsigned long long sa, da, sm, dm, bytes;
+    unsigned long long tot_in = 0, tot_out = 0;
 
     ifs.ignore(1024, '\n');
 
