@@ -1,5 +1,5 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -19,17 +19,18 @@ public:
   NetMeter(XOSView *parent, float max);
   ~NetMeter( void );
 
-  const char *name( void ) const { return "NetMeter"; }  
+  const char *name( void ) const { return "NetMeter"; }
   void checkevent( void );
 
   void checkResources( void );
 protected:
   float maxpackets_;
+  std::string netIface_;
 
 private:
   int _ipsock;
   Timer _timer;
-  unsigned long _lastBytesIn, _lastBytesOut;
+  unsigned long long _lastBytesIn, _lastBytesOut;
   char *_netfilename;
   bool _usechains;
   int _bytesInDev;
